# -*- coding: utf-8 -*-
from setuphelpers import *
from setupdevhelpers import *


app_name = "Flow Launcher"
app_dir = makepath(programfiles, "FlowLauncher")
app_path = makepath(app_dir, "Flow.Launcher.exe")
installed_version = get_file_properties(app_path).get("ProductVersion", "")

def install():
    bin_name = glob.glob("Flow-Launcher*.zip")[0]
    app_dir_version = makepath(app_dir, f"app-{control.get_software_version()}")

    # Uninstall older version before new one
    if installed_version and Version(installed_version) < Version(control.get_software_version()):
        uninstall()

    unzip(bin_name, programfiles)

    # Delete this folder to not store UserData in the App folder but in %appdata%
    remove_tree(makepath(app_dir_version, "UserData"))

    # Disable auto Update
    remove_tree(makepath(app_dir, 'packages'))
    remove_file(makepath(app_dir, 'Update.exe'))

    create_desktop_shortcut(app_name, target=app_path)
    create_programs_menu_shortcut(app_name, target=app_path)

def audit():
    # Auditing software
    audit_status = "OK"
    if Version(installed_version) < Version(control.get_software_version()):
        print(f"{app_name} is installed in version ({installed_version}) instead of ({control.get_software_version()})")
        audit_status = "WARNING"
    elif isdir(app_dir) and not dir_is_empty(app_dir):
        print(f"{app_name} ({installed_version}) is installed")
        audit_status = "OK"
    else:
        print(f"{app_name} is not installed")
        audit_status = "ERROR"
    return audit_status

def uninstall():
    # Uninstalling software
    killalltasks(ensure_list(control.impacted_process))
    if isdir(app_dir):
        remove_tree(app_dir)

    # Removing shortcuts
    remove_desktop_shortcut(app_name)
    remove_programs_menu_shortcut(app_name)